
<?php

/**
* @package com_speventum
* @author JoomShaper http://www.joomshaper.com
* @copyright Copyright (c) 2010 - 2021 JoomShaper
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;

class SpeventumModelSessions extends ListModel
{
	public function __construct(array $config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = [
				'id','a.id',
				'title', 'a.title',
				'ordering', 'a.ordering',
				'created_by', 'a.created_by',
				'created', 'a.created',
				'published', 'a.published',
				'id', 'a.id'
			];
		}
		parent::__construct($config);
	}

	protected function populateState($ordering = 'a.ordering', $direction = 'asc')
	{
		$app = Factory::getApplication();
		$context = $this->context;

		$search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$access = $this->getUserStateFromRequest($this->context . '.filter.access', 'filter_access');
		$this->setState('filter.access', $access);

		$published = $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '');
		$this->setState('filter.published', $published);

		$language = $this->getUserStateFromRequest($this->context . '.filter.language', 'filter_language', '');
		$this->setState('filter.language', $language);

		parent::populateState($ordering, $direction);
	}

	protected function getStoreId($id = '')
	{
		$id .= ':' . $this->getState('filter.search');
		$id .= ':' . $this->getState('filter.access');
		$id .= ':' . $this->getState('filter.published');
		$id .= ':' . $this->getState('filter.language');

		return parent::getStoreId($id);
	}

	protected function getListQuery()
	{
		$app 	= Factory::getApplication();
		$state = $this->get('State');
		$db 	= Factory::getDbo();
		$query = $db->getQuery(true);

		$query->select('a.*, l.title_native as lang');
		$query->from($db->quoteName('#__speventum_sessions', 'a'));
		$query->join('LEFT' , $db->quoteName('#__languages', 'l') . ' ON (' . $db->quoteName('a.language') . ' = ' . $db->quoteName('l.lang_code') . ' )');
		
		// Join over the users for the checked out user.
		$query->select('uc.name AS editor')
			->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');

		$query->select('ua.name AS author_name')
			->join('LEFT', '#__users AS ua ON ua.id = a.created_by');

		$query->select(['s.title AS schedule_title', 's.date AS schedule_date'])
		->join('LEFT', $db->quoteName('#__speventum_schedules', 's') . ' ON (' . $db->quoteName('a.schedule_id') . ' = ' . $db->quoteName('s.id') . ')');
		
		$query->select('ug.title AS access_title')
			->join('LEFT','#__viewlevels AS ug ON ug.id = a.access');

		if ($status = $this->getState('filter.published')) {
			if ($status != '*')
				$query->where($db->quoteName('a.published') . ' = ' . $status);
		} else {
			$query->where($db->quoteName('a.published') . ' IN (0,1)');
		}
		$orderCol 	= $this->getState('list.ordering','a.ordering');
		$orderDirn = $this->getState('list.direction','desc');

		$order = $db->escape($orderCol) . ' ' . $db->escape($orderDirn);
		$query->order($order);

		return $query;
	}

	private function getSpeakers($ids)
	{
		$db 	= Factory::getDbo();
		$query 	= $db->getQuery(true);
		$query->select('id, title, alias')->from($db->quoteName('#__speventum_speakers'))
			->where($db->quoteName('id') . ' IN (' . implode(',', $ids) . ')');
		$db->setQuery($query);

		try
		{
			$speakers = $db->loadObjectList();
			$output = [];

			if (!empty($speakers))
			{
				foreach ($speakers as $speaker)
				{
					$output[] = '<a href="' . Route::_('index.php?option=com_speventum&view=speaker&layout=edit&id=' . $speaker->id . ':' . $speaker->alias) . '">' . $speaker->title . '</a>';
				}
			}

			return $output;
		}
		catch (Exception $e)
		{
			return [];
		}
	}


	private function getDate($session)
	{
		return '<p><strong>' . $session->schedule_title . '</strong>' . ' <span class="muted">(' . HTMLHelper::_('date', $session->schedule_date, 'DATE_FORMAT_LC3') . ')</span></p>' . $session->opening . ' - ' . $session->closing;
	}

	public function getItems()
	{
		$items = parent::getItems();

		foreach ($items as &$item)
		{
			if (!empty($item->speakers))
			{
				$item->speakers = $this->getSpeakers(json_decode($item->speakers, true));
			}

			$item->formattedDate = $this->getDate($item);
		}

		unset($item);

		return $items;
	}
}
	
