<?php

/**
* @package com_speventum
* @author JoomShaper http://www.joomshaper.com
* @copyright Copyright (c) 2010 - 2021 JoomShaper
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/

// No Direct Access
defined ('_JEXEC') or die('Restricted Access');

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Layout\LayoutHelper;

$user 		= Factory::getUser();
$listOrder = $this->escape($this->state->get('list.ordering'));
$listDirn 	= $this->escape($this->state->get('list.direction'));
$canOrder 	= $user->authorise('core.edit.state','com_speventum');
$saveOrder = ($listOrder == 'a.ordering');

if ($saveOrder && !empty($this->items))
{
	if (SpeventumHelper::getVersion() < 4)
	{
		$saveOrderingUrl = 'index.php?option=com_speventum&task=sessions.saveOrderAjax&tmpl=component';
		$html = HTMLHelper::_('sortablelist.sortable', 'sessionList','adminForm', strtolower($listDirn),$saveOrderingUrl);
	}
	else
	{
		$saveOrderingUrl = 'index.php?option=com_speventum&task=sessions.saveOrderAjax&tmpl=component&' . Session::getFormToken() . '= 1';
		HTMLHelper::_('draggablelist.draggable');
	}
}

HTMLHelper::_('jquery.framework', false);
?>

<script type="text/javascript">
window.addEventListener('DOMContentLoaded', e => {
    Joomla.orderTable = function() {
        table = document.getElementById('sortTable');
        direction = document.getElementById('directionTable');
        order = table.options[table.selectedIndex].value;
        if (order != '<?php echo $listOrder; ?>') {
            dirn = 'asc';
        } else {
            dirn = direction.options[direction.selectedIndex].value;
        }
        Joomla.tableOrdering(order, dirn, '');
    }
});
</script>

<form action="<?php echo Route::_('index.php?option=com_speventum&view=sessions'); ?>" method="POST" name="adminForm" id="adminForm">
	<?php if (SpeventumHelper::getVersion() < 4 &&  !empty($this->sidebar)) { ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>

	<div id="j-main-container" class="span10" >
		<?php } else { ?>
			<div id="j-main-container"></div>
		<?php } ?>

		<?php echo LayoutHelper::render('joomla.searchtools.default', array('view' => $this)); ?>
		<div class="clearfix"></div>
		<?php if (!empty($this->items)) { ?>
			<table class="table table-striped" id="sessionList">
				<thead>
					<tr>
						<th class="nowrap center hidden-phone" width="1%">
							<?php echo HTMLHelper::_('grid.sort', '<i class="icon-menu-2"></i>', 'a.ordering', $listDirn, $listOrder, null, 'asc', 'JGRID_HEADING_ORDERING'); ?>
						</th>

						<th width="1%" class="hidden-phone">
							<input type="checkbox" name="checkall-toggle" value="" title="<?php echo Text::_('JGLOBAL_CHECK_ALL'); ?>" onclick="Joomla.checkAll(this)" />
						</th>

						<th width="1%" class="nowrap center">
							<?php echo HTMLHelper::_('grid.sort', 'JSTATUS', 'a.published', $listDirn, $listOrder); ?>
						</th>

						<th>
							<?php echo HTMLHelper::_('grid.sort','JGLOBAL_TITLE','a.title',$listDirn,$listOrder); ?>
						</th>

						<th>
							<?php echo HTMLHelper::_('grid.sort','COM_SPEVENTUM_SESSION_SPEAKERS','a.speakers',$listDirn,$listOrder); ?>
						</th>

						<th>
							<?php echo  Text::_('COM_SPEVENTUM_SESSION_DATE');?>
						</th>
						
						<th>
							<?php echo HTMLHelper::_('grid.sort','COM_SPEVENTUM_SESSION_VENUE','a.venue',$listDirn,$listOrder); ?>
						</th>

					</tr>
				</thead>

				<tfoot>
					<tr>
						<td colspan="10">
							<?php echo $this->pagination->getListFooter(); ?>
						</td>
					</tr>
				</tfoot>

				<?php if (SpeventumHelper::getVersion() < 4) :?>
					<tbody>
				<?php else: ?>
					<tbody <?php if ($saveOrder) :?> class="js-draggable" data-url="<?php echo $saveOrderingUrl; ?>" data-direction="<?php echo strtolower($listDirn); ?>" data-nested="false"<?php endif; ?>>
				<?php endif; ?>
					<?php foreach($this->items as $i => $item): ?>

						<?php
						$canCheckin	= $user->authorise('core.manage', 'com_checkin') || $item->checked_out == $user->get('id') || $item->checked_out == 0;
						$canChange		= $user->authorise('core.edit.state', 'com_speventum') && $canCheckin;
						$canEdit		= $user->authorise( 'core.edit', 'com_speventum' );
						?>

							<?php if (SpeventumHelper::getVersion() < 4) :?>
								<tr>
							<?php else: ?>
								<tr class="row<?php echo $i % 2; ?>" sortable-group-id="1">
							<?php endif; ?>
							<td class="order nowrap center hidden-phone">
								<?php if($canChange) :
									$disableClassName = '';
									$disabledLabel = '';
									if(!$saveOrder) :
										$disabledLabel = Text::_('JORDERINGDISABLED');
										$disableClassName = 'inactive tip-top';
									endif;
									?>

									<span class="sortable-handler hasTooltip <?php echo $disableClassName; ?>" title="<?php echo $disabledLabel; ?>">
										<i class="icon-menu"></i>
									</span>
									<input type="text" style="display: none;" name="order[]" size="5" class="width-20 text-area-order " value="<?php echo $item->ordering; ?>" >
								<?php else: ?>
									<span class="sortable-handler inactive">
										<i class="icon-menu"></i>
									</span>
								<?php endif; ?>
							</td>

							<td class="center hidden-phone">
								<?php echo HTMLHelper::_('grid.id', $i, $item->id); ?>
							</td>

							<td class="center">
								<div class="btn-group">
									<?php echo HTMLHelper::_('jgrid.published', $item->published, $i, 'sessions.', true,'cb');?>
									<?php
										if ($canChange) {
											HTMLHelper::_('actionsdropdown.' . ((int) $item->published === 2 ? 'un' : '') . 'archive', 'cb' . $i, 'sessions');
											HTMLHelper::_('actionsdropdown.' . ((int) $item->published === -2 ? 'un' : '') . 'trash', 'cb' . $i, 'sessions');
											echo HTMLHelper::_('actionsdropdown.render', $this->escape($item->title));
										}
									?>
								</div>
							</td>

							<td>
								<?php if ($item->checked_out) : ?>
									<?php echo HTMLHelper::_('jgrid.checkedout', $i,$item->editor, $item->checked_out_time, 'sessions.', $canCheckin); ?>
								<?php endif; ?>

								<?php if ($canEdit) : ?>
									<a class="title" href="<?php echo Route::_('index.php?option=com_speventum&task=session.edit&id='. $item->id); ?>">
										<?php echo $this->escape($item->title); ?>
									</a>
								<?php else : ?>
									<?php echo $this->escape($item->title); ?>
								<?php endif; ?>
							</td>

							<td>
								<?php if (!empty($item->speakers)): ?>
									<?php echo implode(', ', $item->speakers); ?>
								<?php else: ?>
									<?php echo '...'; ?>
								<?php endif ?>
							</td>

							<td>
								<?php echo $item->formattedDate; ?>
							</td>

							<td>
								<?php echo $item->venue; ?>
							</td>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		<?php } else { ?>
			<?php if (SpeventumHelper::getVersion() < 4) :?>
			<div class="alert alert-no-items">
				<?php echo Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
			<?php else : ?>
				<div class="alert alert-info">
					<span class="icon-info-circle" aria-hidden="true"></span><span class="visually-hidden"><?php echo Text::_('INFO'); ?></span>
					<?php echo Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
				</div>
			<?php endif; ?>
		<?php } ?>

		<input type="hidden" name="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<input type="hidden" name="filter_order" value="<?php echo $listOrder; ?>" />
		<input type="hidden" name="filter_order_Dir" value="<?php echo $lilstDirn; ?>" />
		<?php echo HTMLHelper::_('form.token'); ?>
	</div>
</form>
	
