<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_speventum
 *
 * @copyright   Copyright (C) 2010 - 2021 JoomShaper. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

// No direct access
defined ('_JEXEC') or die ('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Filesystem\File;
use Joomla\CMS\Component\ComponentHelper;

class EventumHelper
{

	//Get Itemid
	public static function getItemid($view) {
		
		$db = Factory::getDbo();
		$query = $db->getQuery(true); 
		$query->select($db->quoteName(array('id')));
		$query->from($db->quoteName('#__menu'));
		$query->where($db->quoteName('link') . ' LIKE '. $db->quote('%'. $view .'%'));
		$query->where($db->quoteName('published') . ' = '. $db->quote('1'));
		$db->setQuery($query);
		$result = $db->loadResult();

		if(!empty($result)) {
			return '&Itemid=' . $result;
		}

		return;
	}

	public static function getThumbs($image) {
		$params = ComponentHelper::getParams('com_speventum');
		$thumb 	= $params->get('speaker_thumbnail', '80x80');

		$filename 		= basename($image);
		$customizePath 	= JPATH_BASE .'/'. dirname($image) . '/thumbs/' . File::stripExt($filename) . '_' . $thumb . '.' . File::getExt($filename);
		$imageSrc		= Uri::base(true) . '/' . dirname($image) . '/thumbs/' . File::stripExt($filename) . '_' . $thumb . '.' . File::getExt($filename);

		if (File::exists($customizePath)) {
			return $imageSrc;
		}
		return Uri::root() . $image;
	}


	//Page Meta
	public static function itemMeta($meta = array()) {
		$config 	= Factory::getConfig();
		$app 		= Factory::getApplication();
		$doc 		= Factory::getDocument();
		$menus   	= $app->getMenu();
		$menu 		= $menus->getActive();
		$title 		= '';

		//Title
		if (isset($meta['title']) && $meta['title']) {
			$title = $meta['title'];
		} else {
			if ($menu) {
				if($menu->getParams()->get('page_title', '')) {
					$title = $menu->getParams()->get('page_title');
				} else {
					$title = $menu->title;
				}
			}
		}

		//Include Site title
		$sitetitle = $title;

		if ($config->get('sitename_pagetitles') == 2)
		{
			$sitetitle = $title . ' | ' . $config->get('sitename');
		}
		elseif ($config->get('sitename_pagetitles') === 1)
		{
			$sitetitle = $config->get('sitename') . ' | ' . $title;
		}

		$doc->setTitle($sitetitle);
		$doc->addCustomTag('<meta content="' . $title . '" property="og:title" />');

		//Keywords
		if (isset($meta['keywords']) && $meta['keywords'])
		{
			$keywords = $meta['keywords'];
			$doc->setMetadata('keywords', $keywords);
		}
		else
		{
			if ($menu)
			{
				if ($menu->getParams()->get('menu-meta_keywords'))
				{
					$keywords = $menu->getParams()->get('menu-meta_keywords');
					$doc->setMetadata('keywords', $keywords);
				}
			}
		}

		//Metadescription
		if (isset($meta['metadesc']) && $meta['metadesc'])
		{
			$metadesc = $meta['metadesc'];
			$doc->setDescription($metadesc);
			$doc->addCustomTag('<meta content="'. $metadesc .'" property="og:description" />');
		}
		else
		{
			if ($menu)
			{
				if ($menu->getParams()->get('menu-meta_description'))
				{
					$metadesc = $menu->getParams()->get('menu-meta_description');
					$doc->setDescription($menu->getParams()->get('menu-meta_description'));
					$doc->addCustomTag('<meta content="'. $metadesc .'" property="og:description" />');
				}
			}
		}

		//Robots
		if ($menu) {
			if ($menu->getParams()->get('robots'))
			{
				$doc->setMetadata('robots', $menu->getParams()->get('robots'));
			}
		}

		//Open Graph
		foreach ( $doc->_links as $k => $array )
		{
			if ( $array['relation'] == 'canonical' )
			{
				unset($doc->_links[$k]);
			}
		} // Remove Joomla canonical

		$doc->addCustomTag('<meta content="website" property="og:type"/>');
		$doc->addCustomTag('<link href="' . Uri::current().'" rel="canonical" />');
		$doc->addCustomTag('<meta content="' . Uri::current().'" property="og:url" />');

		if (isset($meta['image']) && $meta['image'])
		{
			$doc->addCustomTag('<meta content="'. $meta['image'] .'" property="og:image" />');
		}

	}

}