
<?php
/**
* @package com_speventum
* @author JoomShaper http://www.joomshaper.com
* @copyright Copyright (c) 2010 - 2021 JoomShaper
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Model\ItemModel;
use Joomla\CMS\Language\Multilanguage;

class SpeventumModelSpeaker extends ItemModel
{
    protected $_context = 'com_speventum.speaker';

    protected function populateState() {
		$app = Factory::getApplication('site');
		$itemId = $app->input->getInt('id');
		$this->setState('speaker.id', $itemId);
		$this->setState('filter.language', Multilanguage::isEnabled());
	}

    public function getItem( $itemId = null ) {
		$user = Factory::getUser();
		$itemId = (!empty($itemId))? $itemId : (int)$this->getState('speaker.id');
		
		if ( $this->_item == null ) {
			$this->_item = array();
		}

		if (!isset($this->_item[$itemId])) {
			try {
				$db = $this->getDbo();
				$query = $db->getQuery(true);
				$query->select('a.*');
				$query->from($db->quoteName('#__speventum_speakers', 'a'));
				$query->where('a.id = ' . (int) $itemId);
				
				// Filter by published state.
				$query->where('a.published = 1');

				if ($this->getState('filter.language')) {
					$query->where('a.language in (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
				}

				//Authorised
				$groups = implode(',', $user->getAuthorisedViewLevels());
				$query->where('a.access IN (' . $groups . ')');

				$db->setQuery($query);
				$data = $db->loadObject();

				$this->_item[$itemId] = $data;
			}
			catch (Exception $e) {
				if ($e->getCode() == 404 ) {
					JError::raiseError(404, $e->getMessage());
				} else {
					$this->setError($e);
					$this->_item[$itemId] = false;
				}
			}
        }
		return $this->_item[$itemId];
    }

	public function getSpeaker($id = NULL)
	{
		$db = Factory::getDbo();
		$query = $db->getQuery(true);
		$query->select( array('a.*') );
	    $query->from($db->quoteName('#__speventum_speakers', 'a'));
	    $query->where($db->quoteName('a.id')." = ".$db->quote($id));
	    $query->where($db->quoteName('a.published')." = ".$db->quote('1'));
	    //Language
		$query->where('a.language in (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
	    //Access
		$query->where($db->quoteName('a.access')." IN (" . implode( ',', Factory::getUser()->getAuthorisedViewLevels() ) . ")");
	    $db->setQuery($query);
		$speaker = $db->loadObject();

		if (empty($speaker))
		{
			throw new Exception(Text::_('COM_SPEVENTUM_SPEAKER_NOT_FOUND'), 404);
		}

		return $speaker;

	}

	/**
	 * Get sessions for a speaker.
	 *
	 * @param	int		$speakerId		The speaker ID.
	 *
	 * @return	array					The sessions.
	 */
	public function getSessionsForSpeaker($speakerId)
	{
		$sessions = array();

		try
		{
			$db 	= Factory::getDbo();
			$query 	= $db->getQuery(true);

			$query->select('*')->from($db->quoteName('#__speventum_sessions'))
				->where($db->quoteName('speakers') . ' LIKE ' . $db->quote('%"' . $speakerId . '"%'))
				->where($db->quoteName('published') . ' = 1')
				->where('language in (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
			$query->order($db->quoteName('created') . ' DESC');

			$db->setQuery($query);

			$sessions = $db->loadObjectList();
		}
		catch (Exception $e)
		{
			echo $e->getMessage();

			return array();
		}

		return $sessions;
	}

}
    
