
<?php
/**
* @package com_speventum
* @author JoomShaper http://www.joomshaper.com
* @copyright Copyright (c) 2010 - 2021 JoomShaper
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\CMS\Language\Multilanguage;

jimport( 'joomla.application.component.helper' );

class SpeventumModelSpeakers extends ListModel
{
	protected function populateState($ordering = null, $direction = null)
	{
		$app = Factory::getApplication('site');
		$this->setState('list.start', $app->input->get('limitstart', 0, 'uint'));
		$this->setState('filter.language', Multilanguage::isEnabled());
	}

	protected function getListQuery()
	{
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		$query->select('a.*');
	  	$query->from($db->quoteName('#__speventum_speakers', 'a'));

        $query->where($db->quoteName('a.published') . ' = ' . $db->quote('1'));

        if ($this->getState('filter.language')) {
            $query->where($db->quoteName('a.language') . ' IN (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
        }
		return $query;
	}

	public function getKeynoteSpeakers() {
		$db = Factory::getDbo();
		$query = $db->getQuery(true);
		$query->select( array('a.*') );
	    $query->from($db->quoteName('#__speventum_speakers', 'a'));
	    $query->where($db->quoteName('a.keynote')." = ".$db->quote('1'));
	    $query->where($db->quoteName('a.published')." = ".$db->quote('1'));

	    //Language
		$query->where('a.language in (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
	    //Access
		$query->where($db->quoteName('a.access')." IN (" . implode( ',', Factory::getUser()->getAuthorisedViewLevels() ) . ")");
	    $query->order($db->quoteName('a.ordering') . ' ASC');
	    $db->setQuery($query);
		$speakers = $db->loadObjectList();

	    return $speakers;
	}

	/**
	 * Get sessions for a speaker.
	 *
	 * @param	int		$speakerId		The speaker ID.
	 *
	 * @return	array					The sessions.
	 */
	public function getSessionsForSpeaker($speakerId)
	{
		$sessions = array();

		try
		{
			$db 	= Factory::getDbo();
			$query 	= $db->getQuery(true);

			$query->select('*')->from($db->quoteName('#__speventum_sessions'))
				->where($db->quoteName('speakers') . ' LIKE ' . $db->quote('%"' . $speakerId . '"%'))
				->where($db->quoteName('published') . ' = 1')
				->where('language in (' . $db->quote(Factory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
			$query->order($db->quoteName('created') . ' DESC');

			$db->setQuery($query);

			$sessions = $db->loadObjectList();
		}
		catch (Exception $e)
		{
			echo $e->getMessage();

			return array();
		}

		return $sessions;
	}

}
    
